==> haskell-integer-logarithms-1.0.4-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-integer-logarithms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 integer-logarithms
version:              1.0.4
visibility:           public
id:                   integer-logarithms-1.0.4-IeiZNOHndtHBlUxCWzOJUr
key:                  integer-logarithms-1.0.4-IeiZNOHndtHBlUxCWzOJUr
license:              MIT
copyright:
    (c) 2011 Daniel Fischer, 2017-2020 Oleg Grenrus, Andrew Lelechenko

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Daniel Fischer
stability:            Provisional
homepage:             https://github.com/haskellari/integer-logarithms
synopsis:             Integer logarithms.
description:
    "Math.NumberTheory.Logarithms" and "Math.NumberTheory.Powers.Integer"
    from the arithmoi package.

    Also provides "GHC.Integer.Logarithms.Compat" and
    "Math.NumberTheory.Power.Natural" modules, as well as some
    additional functions in migrated modules.

category:             Math, Algorithms, Number Theory
abi:                  b1730ce1d26f14bec7f1b8a6131ce992
exposed:              True
exposed-modules:
    GHC.Integer.Logarithms.Compat Math.NumberTheory.Logarithms
    Math.NumberTheory.Powers.Integer Math.NumberTheory.Powers.Natural

import-dirs:          /usr/lib/ghc-9.4.8/site-local/integer-logarithms-1.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/integer-logarithms-1.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/integer-logarithms-1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-integer-logarithms
hs-libraries:         HSinteger-logarithms-1.0.4-IeiZNOHndtHBlUxCWzOJUr
depends:
    array-0.5.4.0 base-4.17.2.1 ghc-bignum-1.3 ghc-prim-0.9.1

haddock-interfaces:
    /usr/share/doc/haskell-integer-logarithms/html/integer-logarithms.haddock

haddock-html:         /usr/share/doc/haskell-integer-logarithms/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-integer-logarithms-1.0.4-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-integer-logarithms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 integer-logarithms
version:              1.0.4
visibility:           public
id:                   integer-logarithms-1.0.4-B4xdIn5EqPvMTifdxHklv
key:                  integer-logarithms-1.0.4-B4xdIn5EqPvMTifdxHklv
license:              MIT
copyright:
    (c) 2011 Daniel Fischer, 2017-2020 Oleg Grenrus, Andrew Lelechenko

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Daniel Fischer
stability:            Provisional
homepage:             https://github.com/haskellari/integer-logarithms
synopsis:             Integer logarithms.
description:
    "Math.NumberTheory.Logarithms" and "Math.NumberTheory.Powers.Integer"
    from the arithmoi package.

    Also provides "GHC.Integer.Logarithms.Compat" and
    "Math.NumberTheory.Power.Natural" modules, as well as some
    additional functions in migrated modules.

category:             Math, Algorithms, Number Theory
abi:                  edc3f7213534d3ea6e626d458542422c
exposed:              True
exposed-modules:
    GHC.Integer.Logarithms.Compat Math.NumberTheory.Logarithms
    Math.NumberTheory.Powers.Integer Math.NumberTheory.Powers.Natural

import-dirs:          /usr/lib/ghc-9.4.8/site-local/integer-logarithms-1.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/integer-logarithms-1.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/integer-logarithms-1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-integer-logarithms
hs-libraries:         HSinteger-logarithms-1.0.4-B4xdIn5EqPvMTifdxHklv
depends:
    array-0.5.4.0 base-4.17.2.1 ghc-bignum-1.3 ghc-prim-0.9.1

haddock-interfaces:
    /usr/share/doc/haskell-integer-logarithms/html/integer-logarithms.haddock

haddock-html:         /usr/share/doc/haskell-integer-logarithms/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
